@@ -62,7 +62,6 @@ def predict(
         target_shape.append(len(offsets))
     else:
         target_shape[-1] = len(offsets)
-    target_shape.append(1)
 
     arr = np.zeros(target_shape, dtype="float32")
     weights = np.zeros(target_shape, dtype="float32")
@@ -97,19 +96,11 @@ def predict(
         arr[sx:ex, sy:ey, idx] = pred_reshaped
         weights[sx:ex, sy:ey, idx] = pred_weights_reshaped
 
-        import pdb; pdb.set_trace()
-
-    weights_sum = np.sum(weights, axis=2)
-    weights_norm = (weights[:, :, :, 0] / weights_sum)[:, :, :, np.newaxis]
-
-    # What is going on with dimensions here?
-    import pdb; pdb.set_trace()
-
-    weights = weights[:, :, :, 0]
-    arr = arr[:, :, :, 0]
+    weights_norm = (weights / np.sum(weights, axis=2))
 
     merged = None
     if merge_method == "mean":
+        import pdb; pdb.set_trace()
         merged = np.average(arr, axis=2, weights=weights_norm)
 
     elif merge_method == "max":
